==> zio-aws-chimesdkmessaging_2.13-5.17.148.1-sources.jar: zio/aws/chimesdkmessaging/model/BatchCreateChannelMembershipRequest.scala <==
package zio.aws.chimesdkmessaging.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.chimesdkmessaging.model.primitives.ChimeArn
import scala.jdk.CollectionConverters._
final case class BatchCreateChannelMembershipRequest(
    channelArn: ChimeArn,
    `type`: Option[zio.aws.chimesdkmessaging.model.ChannelMembershipType] =
      None,
    memberArns: Iterable[ChimeArn],
    chimeBearer: ChimeArn
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.chimesdkmessaging.model.BatchCreateChannelMembershipRequest = {
    import BatchCreateChannelMembershipRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.chimesdkmessaging.model.BatchCreateChannelMembershipRequest
      .builder()
      .channelArn(ChimeArn.unwrap(channelArn): java.lang.String)
      .optionallyWith(`type`.map(value => value.unwrap))(_.`type`)
      .memberArns(memberArns.map { item =>
        ChimeArn.unwrap(item): java.lang.String
      }.asJavaCollection)
      .chimeBearer(ChimeArn.unwrap(chimeBearer): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.chimesdkmessaging.model.BatchCreateChannelMembershipRequest.ReadOnly =
    zio.aws.chimesdkmessaging.model.BatchCreateChannelMembershipRequest
      .wrap(buildAwsValue())
}
object BatchCreateChannelMembershipRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.chimesdkmessaging.model.BatchCreateChannelMembershipRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.chimesdkmessaging.model.BatchCreateChannelMembershipRequest =
      zio.aws.chimesdkmessaging.model.BatchCreateChannelMembershipRequest(
        channelArn,
        `type`.map(value => value),
        memberArns,
        chimeBearer
      )
    def channelArn: ChimeArn
    def `type`: Option[zio.aws.chimesdkmessaging.model.ChannelMembershipType]
    def memberArns: List[ChimeArn]
    def chimeBearer: ChimeArn
    def getChannelArn: ZIO[Any, Nothing, ChimeArn] = ZIO.succeed(channelArn)
    def getType: ZIO[
      Any,
      AwsError,
      zio.aws.chimesdkmessaging.model.ChannelMembershipType
    ] = AwsError.unwrapOptionField("type", `type`)
    def getMemberArns: ZIO[Any, Nothing, List[ChimeArn]] =
      ZIO.succeed(memberArns)
    def getChimeBearer: ZIO[Any, Nothing, ChimeArn] = ZIO.succeed(chimeBearer)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.BatchCreateChannelMembershipRequest
  ) extends zio.aws.chimesdkmessaging.model.BatchCreateChannelMembershipRequest.ReadOnly {
    override val channelArn: ChimeArn =
      zio.aws.chimesdkmessaging.model.primitives.ChimeArn(impl.channelArn())
    override val `type`
        : Option[zio.aws.chimesdkmessaging.model.ChannelMembershipType] = scala
      .Option(impl.`type`())
      .map(value =>
        zio.aws.chimesdkmessaging.model.ChannelMembershipType.wrap(value)
      )
    override val memberArns: List[ChimeArn] = impl
      .memberArns()
      .asScala
      .map { item =>
        zio.aws.chimesdkmessaging.model.primitives.ChimeArn(item)
      }
      .toList
    override val chimeBearer: ChimeArn =
      zio.aws.chimesdkmessaging.model.primitives.ChimeArn(impl.chimeBearer())
  }
  def wrap(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.BatchCreateChannelMembershipRequest
  ): zio.aws.chimesdkmessaging.model.BatchCreateChannelMembershipRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-chimesdkmessaging_2.13-5.17.239.4-sources.jar: zio/aws/chimesdkmessaging/model/BatchCreateChannelMembershipRequest.scala <==
package zio.aws.chimesdkmessaging.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.chimesdkmessaging.model.primitives.ChimeArn
import scala.jdk.CollectionConverters._
final case class BatchCreateChannelMembershipRequest(
    channelArn: ChimeArn,
    `type`: Optional[zio.aws.chimesdkmessaging.model.ChannelMembershipType] =
      Optional.Absent,
    memberArns: Iterable[ChimeArn],
    chimeBearer: ChimeArn
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.chimesdkmessaging.model.BatchCreateChannelMembershipRequest = {
    import BatchCreateChannelMembershipRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.chimesdkmessaging.model.BatchCreateChannelMembershipRequest
      .builder()
      .channelArn(ChimeArn.unwrap(channelArn): java.lang.String)
      .optionallyWith(`type`.map(value => value.unwrap))(_.`type`)
      .memberArns(memberArns.map { item =>
        ChimeArn.unwrap(item): java.lang.String
      }.asJavaCollection)
      .chimeBearer(ChimeArn.unwrap(chimeBearer): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.chimesdkmessaging.model.BatchCreateChannelMembershipRequest.ReadOnly =
    zio.aws.chimesdkmessaging.model.BatchCreateChannelMembershipRequest
      .wrap(buildAwsValue())
}
object BatchCreateChannelMembershipRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.chimesdkmessaging.model.BatchCreateChannelMembershipRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.chimesdkmessaging.model.BatchCreateChannelMembershipRequest =
      zio.aws.chimesdkmessaging.model.BatchCreateChannelMembershipRequest(
        channelArn,
        `type`.map(value => value),
        memberArns,
        chimeBearer
      )
    def channelArn: ChimeArn
    def `type`: Optional[zio.aws.chimesdkmessaging.model.ChannelMembershipType]
    def memberArns: List[ChimeArn]
    def chimeBearer: ChimeArn
    def getChannelArn: ZIO[Any, Nothing, ChimeArn] = ZIO.succeed(channelArn)
    def getType: ZIO[
      Any,
      AwsError,
      zio.aws.chimesdkmessaging.model.ChannelMembershipType
    ] = AwsError.unwrapOptionField("type", `type`)
    def getMemberArns: ZIO[Any, Nothing, List[ChimeArn]] =
      ZIO.succeed(memberArns)
    def getChimeBearer: ZIO[Any, Nothing, ChimeArn] = ZIO.succeed(chimeBearer)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.BatchCreateChannelMembershipRequest
  ) extends zio.aws.chimesdkmessaging.model.BatchCreateChannelMembershipRequest.ReadOnly {
    override val channelArn: ChimeArn =
      zio.aws.chimesdkmessaging.model.primitives.ChimeArn(impl.channelArn())
    override val `type`
        : Optional[zio.aws.chimesdkmessaging.model.ChannelMembershipType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.`type`())
        .map(value =>
          zio.aws.chimesdkmessaging.model.ChannelMembershipType.wrap(value)
        )
    override val memberArns: List[ChimeArn] = impl
      .memberArns()
      .asScala
      .map { item =>
        zio.aws.chimesdkmessaging.model.primitives.ChimeArn(item)
      }
      .toList
    override val chimeBearer: ChimeArn =
      zio.aws.chimesdkmessaging.model.primitives.ChimeArn(impl.chimeBearer())
  }
  def wrap(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.BatchCreateChannelMembershipRequest
  ): zio.aws.chimesdkmessaging.model.BatchCreateChannelMembershipRequest.ReadOnly =
    new Wrapper(impl)
}
